Index: /trunk/src/VBox/Main/xml/Settings.cpp
===================================================================
--- /trunk/src/VBox/Main/xml/Settings.cpp	(revision 35148)
+++ /trunk/src/VBox/Main/xml/Settings.cpp	(revision 35149)
@@ -1035,8 +1035,10 @@
             mdm.hdType == MediumType_MultiAttach ? "MultiAttach" :
             "INVALID";
-        // no need to save the usual DVD medium types
-        if (devType != DeviceType_DVD || (   mdm.hdType != MediumType_Normal
-                                          && mdm.hdType != MediumType_Writethrough
-                                          && mdm.hdType != MediumType_Readonly))
+        // no need to save the usual DVD/floppy medium types
+        if (   (   devType != DeviceType_DVD
+                || (   mdm.hdType != MediumType_Writethrough // shouldn't happen
+                    && mdm.hdType != MediumType_Readonly))
+            && (   devType != DeviceType_Floppy
+                || mdm.hdType != MediumType_Writethrough))
             pelmMedium->setAttribute("type", pcszType);
     }
